OC.L10N.register(
    "federation",
    {
    "Server added to the list of trusted ownClouds" : "Server wurde in die Liste der vertrauenswürdigen Servern aufgenommen",
    "Server is already in the list of trusted servers." : "Server ist bereits in der Liste der vertrauenswürdigen Servern.",
    "No ownCloud server found" : "Es wurde kein ownCloud Server gefunden",
    "Could not add server" : "Konnte Server nicht hinzufügen",
    "Federation" : "Federation",
    "ownCloud Federation allows you to connect with other trusted ownClouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "ownCloud Federation ermöglicht es dir dich mit anderen vertrauenswürdigen Servern zu verbinden um das Benutzerverzeichnis auszutauschen. Dies wird, zum Beispiel, für die automatische Vervollständigung externer Benutzer verwendet.",
    "Add server automatically once a federated share was created successfully" : "Füge einen mit ownCloud Federation verbundenen Server automatisch hinzu, sobald die Verbindung einmal erfolgreich erstellt wurde",
    "Trusted ownCloud Servers" : "vertrauenswürdige ownCloud Server",
    "+ Add ownCloud server" : "+ ownCloud Server hinzufügen",
    "ownCloud Server" : "ownCloud Server"
},
"nplurals=2; plural=(n != 1);");
